========
Dragline
========

[![PyPI version](https://badge.fury.io/py/Dragline.svg)](http://badge.fury.io/py/Dragline)

Dragline is a distributed Python web crawling framework.

Features :
---------
* Distributed, scalable and persistent crawling
* Efficient lightweight parallel execution based on gevent
* Redis backend for distributed and uninterrupted crawling


Requirements
------------

* Python 2.7
* Works on Linux
* Redis


Install
-------

The quick way :

    pip install --pre dragline


Download the latest release from [Python Package Index] or clone [the repository].


[Python Package Index]: http://pypi.python.org/pypi/dragline
[the repository]: https://github.com/inzyte/dragline